@@ -5,7 +5,13 @@
 #define QT_PRODUCT_LICENSE  "qt-free"
 
 /* Build key */
-#define QT_BUILD_KEY "amd64 OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "sparc64 OpenBSD g++-3.* full-config"
+
+/* Machine byte-order */
+#define Q_BIG_ENDIAN 4321
+#define Q_LITTLE_ENDIAN 1234
+#define Q_BYTE_ORDER Q_BIG_ENDIAN
 
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
+#define QT_POINTER_SIZE 8
