@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qnamespace.h   3.1.2   edited Jan 17 05:12 $
+** $Id: qt/qnamespace.h   3.3.2   edited Dec 13 17:15 $
 **
 ** Definition of Qt namespace (as class for compiler compatibility)
 **
 ** Created : 980927
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -91,6 +91,12 @@ public:
 	Vertical
     };
 
+    // documented in qlistview.cpp
+    enum SortOrder {
+	Ascending,
+	Descending
+    };
+
     // Text formatting flags for QPainter::drawText and QLabel
     // the following four enums can be combined to one integer which
     // is passed as textflag to drawText and qt_format_text.
@@ -118,7 +124,13 @@ public:
 	ShowPrefix	= 0x0400,
 	WordBreak	= 0x0800,
 	BreakAnywhere = 0x1000,
-	DontPrint	= 0x2000,		// internal
+#ifndef Q_QDOC
+	DontPrint	= 0x2000,
+	Underline = 0x01000000,
+	Overline  = 0x02000000,
+	StrikeOut = 0x04000000,
+	IncludeTrailingSpaces = 0x08000000,
+#endif
 	NoAccel = 0x4000
     };
 
@@ -143,8 +155,8 @@ public:
 	WState_Polished		= 0x00002000,
 	WState_DND		= 0x00004000,
 	WState_Reserved0	= 0x00008000,
-	WState_Reserved1	= 0x00010000,
-	WState_Reserved2	= 0x00020000,
+	WState_FullScreen	= 0x00010000,
+	WState_OwnSizePolicy	= 0x00020000,
 	WState_CreatedHidden	= 0x00040000,
 	WState_Maximized	= 0x00080000,
 	WState_Minimized	= 0x00100000,
@@ -183,10 +195,10 @@ public:
 	WPaintDesktop		= 0x00020000,
 	WPaintUnclipped		= 0x00040000,
 	WPaintClever		= 0x00080000,
-	WResizeNoErase		= 0x00100000,
+	WResizeNoErase		= 0x00100000, // OBSOLETE
 	WMouseNoMask		= 0x00200000,
 	WStaticContents		= 0x00400000,
-	WRepaintNoErase		= 0x00800000,
+	WRepaintNoErase		= 0x00800000, // OBSOLETE
 #if defined(Q_WS_X11)
 	WX11BypassWM		= 0x01000000,
 	WWinOwnDC		= 0x00000000,
@@ -203,21 +215,34 @@ public:
 	WMacNoSheet             = 0x00000000,
         WMacDrawer              = 0x00000000,
 #endif
-	WGroupLeader 		= 0x02000000,
-	WShowModal 	       	= 0x04000000,
+	WGroupLeader		= 0x02000000,
+	WShowModal		= 0x04000000,
 	WNoMousePropagation	= 0x08000000,
 	WSubWindow              = 0x10000000,
-	WStyle_Splash           = WStyle_NoBorder | WStyle_StaysOnTop | WMacNoSheet |
-	                          WStyle_Tool | WX11BypassWM | WWinOwnDC
+#if defined(Q_WS_X11)
+        WStyle_Splash           = 0x20000000,
+#else
+	WStyle_Splash           = WStyle_NoBorder | WMacNoSheet | WStyle_Tool | WWinOwnDC,
+#endif
+	WNoAutoErase		= WRepaintNoErase | WResizeNoErase
 #ifndef QT_NO_COMPAT
 	,
 	WNorthWestGravity	= WStaticContents,
 	WType_Modal		= WType_Dialog | WShowModal,
-	WStyle_Dialog 		= WType_Dialog,
+	WStyle_Dialog		= WType_Dialog,
 	WStyle_NoBorderEx	= WStyle_NoBorder
 #endif
     };
 
+    enum WindowState {
+	WindowNoState   = 0x00000000,
+	WindowMinimized = 0x00000001,
+	WindowMaximized = 0x00000002,
+	WindowFullScreen = 0x00000004,
+	WindowActive = 0x00000008
+    };
+
+
     // Image conversion flags.  The unusual ordering is caused by
     // compatibility and default requirements.
     // Documented in qimage.cpp
@@ -676,11 +701,16 @@ public:
 
 	//Version numbers
 	MV_9            = 0x0001,
-	MV_10_DOT_1     = 0x0002,
-	MV_10_DOT_2     = 0x0003,
+	MV_10_DOT_0     = 0x0002,
+	MV_10_DOT_1     = 0x0003,
+	MV_10_DOT_2     = 0x0004,
+	MV_10_DOT_3     = 0x0005,
 
 	//Code names
-	MV_JAGUAR       = MV_10_DOT_2
+	MV_CHEETAH      = MV_10_DOT_0,
+	MV_PUMA         = MV_10_DOT_1,
+	MV_JAGUAR       = MV_10_DOT_2,
+	MV_PANTHER      = MV_10_DOT_3
     };
 
     // documented in qapplication_win.cpp
@@ -694,7 +724,12 @@ public:
 	WV_NT 		= 0x0010,
 	WV_2000 	= 0x0020,
 	WV_XP		= 0x0030,
-	WV_NT_based	= 0x00f0
+	WV_2003		= 0x0040,
+	WV_NT_based	= 0x00f0,
+
+	WV_CE           = 0x0100,
+	WV_CENET	= 0x0200,
+	WV_CE_based	= 0x0f00
     };
 
     // documented in qstyle.cpp
@@ -704,7 +739,8 @@ public:
 	UI_FadeMenu,
 	UI_AnimateCombo,
 	UI_AnimateTooltip,
-	UI_FadeTooltip
+	UI_FadeTooltip,
+	UI_AnimateToolBox
     };
 
     // documented in qcursor.cpp
@@ -725,7 +761,8 @@ public:
 	PointingHandCursor,
 	ForbiddenCursor,
 	WhatsThisCursor,
-	LastCursor	= WhatsThisCursor,
+	BusyCursor,
+	LastCursor	= BusyCursor,
 	BitmapCursor	= 24
     };
 
@@ -749,6 +786,7 @@ public:
     QT_STATIC_CONST QCursor & pointingHandCursor;	// pointing hand
     QT_STATIC_CONST QCursor & forbiddenCursor;	// forbidden cursor (slashed circle)
     QT_STATIC_CONST QCursor & whatsThisCursor;  // arrow with a question mark
+    QT_STATIC_CONST QCursor & busyCursor;	// arrow with hourglass
 
 
     enum TextFormat {
@@ -791,7 +829,7 @@ public:
     enum DateFormat {
 	TextDate,      // default Qt
 	ISODate,       // ISO 8601
-	LocalDate      // locale dependant
+	LocalDate      // locale dependent
     };
 
     // documented in qdatetime.cpp
@@ -835,6 +873,14 @@ public:
         ExactMatch      = 0x00010  // 1 0000
     };
 
+    // Documented in qtabwidget.cpp
+    enum Corner {
+	TopLeft     = 0x00000,
+	TopRight    = 0x00001,
+	BottomLeft  = 0x00002,
+	BottomRight = 0x00003
+    };
+
     // "handle" type for system objects. Documented as \internal in
     // qapplication.cpp
 #if defined(Q_WS_MAC)
